library(growth)
library(gnlm)
library(repeated)
options(contrasts=c("contr.mean","contr.poly"))

data <- read.table("cake.dat",skip=3,header=T)
reps <- rmna(restovec(cbind(data[1:15,2:7],data[16:30,2:7],data[31:45,2:7]),
	name="y",nest=c(rep(1,6),rep(2,6),rep(3,6)),times=rep(1:6,3)),
	tvcov=tvctomat(cbind(matrix(1,ncol=6,nrow=15),matrix(2,ncol=6,nrow=15),
	matrix(3,ncol=6,nrow=15)),name="Recipe"))
# times=Temperature

# normal
aov(lm(y~as.factor(individuals)+as.factor(Recipe)/as.factor(individuals)+
	as.factor(Recipe)*as.factor(times),data=reps))
print(zf0 <- elliptic(reps,model="linear",tvcov=~individuals),corr=F) # 855.56
print(zltr <- elliptic(reps,model="linear",tvcov=~times+as.factor(Recipe)),
	corr=F) # 939.5198
print(zfltr <- elliptic(reps,model="linear",tvcov=~individuals+
	times+as.factor(Recipe)),corr=F) # 817.041
print(zf <- elliptic(reps,model="linear",tvcov=~individuals+
	as.factor(Recipe)*as.factor(times)),corr=F) # 822.9495

# normal-normal
print(zre <- elliptic(reps,model="linear",pre=10,
	tvcov=~as.factor(Recipe)*as.factor(times)),corr=F) # 843.554
print(zltrre <- elliptic(reps,model="linear",pre=10,
	tvcov=~times+as.factor(Recipe)),corr=F) # 837.196
print(zre2 <- elliptic(reps,model="linear",pre=c(10,2),
	tvcov=~as.factor(Recipe)*as.factor(times)),corr=F) # 840.2225

print(hnlmix(reps,mu=~a+rep+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5),random="rep",
	pmu=c(35,-7,-5,-4,-3,0.5),psh=10,prand=c(zf$beta[2:15],0)),
	corr=F) # 819.2587
print(hnlmix(reps,mu=~a+rep+b1*times+c1*(Recipe==1)+c2*(Recipe==2),
	random="rep",pmu=c(35,0,0,0),psh=10,
	prand=c(zf$beta[2:15],0)),corr=F) # 817.2237
print(hnlmix(reps,mu=~a+rep+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2),
	random="rep",pmu=c(35,-7,-5,-4,-3,0.5,0,0),psh=10,
	prand=c(zf$beta[2:15],0)),corr=F) # 818.0955

# normal-inverse gamma
print(gnlmix(reps,mu=~rep*a+b1*times+c1*(Recipe==1)+c2*(Recipe==2),
	dist="normal",mixture="inverse gamma",random="rep",psh=3.13,
	pmix=3.22,pmu=c(24.91,1.59,1.54,0.065)),corr=F) # 834.6284
#	dist="normal",mixture="inverse gamma",random="rep",psh=3.82,
#	pmix=3.61,pmu=zfltr$beta[c(1,16:18)]),corr=F) # 834.6284

print(hnlmix(reps,mu=~rep*a+b1*times+c1*(Recipe==1)+c2*(Recipe==2),
	dist="normal",mixture="inverse gamma",random="rep",
	pmu=zfltr$beta[c(1,16:18)],psh=3.85,prand=1.01,iter=400),corr=F) # 816.2999

# normal with log link
aov(glm(y~as.factor(individuals)+as.factor(Recipe)/as.factor(individuals)+
	as.factor(Recipe)*as.factor(times),family=gaussian(link=log),
	data=reps))
print(znf0 <- gnlr(reps,mu=~exp(linear),linear=~individuals,
	pmu=c(4,rep(0,14)),psh=30),corr=F) # 855.56
print(znltr <- gnlr(reps,mu=~exp(linear),linear=~times+as.factor(Recipe),
	pmu=c(3.3,rep(0,3)),psh=4),corr=F) # 939.6343
print(znfn <- gnlr(reps,mu=~exp(linear),
	linear=~as.factor(Recipe)*as.factor(times),
	pmu=c(4,rep(0,17)),psh=30),corr=F) # 950.6314
print(znfltr <- gnlr(reps,mu=~exp(linear),linear=~individuals+
	times+as.factor(Recipe),pmu=c(4,rep(0,17)),psh=30),corr=F) # 817.7814
print(znf <- gnlr(reps,mu=~exp(linear),linear=~individuals+
	as.factor(Recipe)*as.factor(times),
	pmu=c(4,rep(0,31)),psh=30),corr=F) # 822.1398
print(znfn2 <- elliptic(reps,model="linear",link="log",preg=znfn$coef[1:18],
	tvcov=~as.factor(Recipe)*as.factor(times)),corr=F) # 950.6314

# normal-normal with log link
print(znre <- elliptic(reps,model="linear",link="log",preg=znfn$coef[1:18],
	pre=10,tvcov=~as.factor(Recipe)*as.factor(times)),corr=F) # 843.554
print(znltrre <- elliptic(reps,model="linear",link="log",
	preg=znfltr$coef[c(1,16:18)],pre=10,tvcov=~times+as.factor(Recipe)),
	corr=F) # 837.4927
print(znre2 <- elliptic(reps,model="linear",link="log",preg=znfn$coef[1:18],
	pre=c(10,3),tvcov=~as.factor(Recipe)*as.factor(times)),corr=F)
	# 840.2225

print(znmmltr <- gnlmm(reps,dist="normal",mu=~exp(linear),
	linear=~times+as.factor(Recipe),pmu=znfltr$coef[c(1,16:18)],
	psh=3.84,psd=0.5,points=5),corr=F) # 911.2953
print(znmmltr2 <- gnlmm(reps,dist="normal",mu=~exp(linear),scale="log",
	linear=~times+as.factor(Recipe),pmu=znfltr$coef[c(1,16:18)],
	psh=3.8,psd=0.02,points=5),corr=F) # 865.2438

print(hnlmix(reps,mu=~exp(a+rep+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5)),random="rep",
	pmu=c(3.5,znfn$coef[3:7]),psh=10,prand=c(znf$coef[19:32],0)),corr=F)
	# 819.9147 
print(hnlmix(reps,mu=~exp(a+rep+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	random="rep",pmu=znfltr$coef[c(1,16:18)],psh=10,
	prand=c(znfltr$coef[2:15],0)),corr=F) # 817.7814
print(hnlmix(reps,mu=~exp(a+rep+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)),
	random="rep",pmu=znf$coef[c(1,16:22)],psh=10,
	prand=c(znf$coef[2:15],0)),corr=F) #  817.9275
print(hnlmix(reps,mu=~exp(a+rep+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
	e4*(times==4)+e5*(times==5))*(Recipe==2)),
	random="rep",pmu=znf$coef[c(1,16:32)],psh=10,
	prand=c(znf$coef[2:15],0)),corr=F) # 822.8748

# normal-inverse gamma with log link
print(gnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="normal",mixture="inverse gamma",random="rep",psh=3.13,
	pmix=3.61,pmu=c(3.25,0.049,0.033,-0.00024)),corr=F) # 
#	dist="normal",mixture="inverse gamma",random="rep",psh=3.82,
#	pmix=3.61,pmu=znfltr$coef[c(1,16:18)]),corr=F) # 

print(hnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="normal",mixture="inverse gamma",random="rep",
	pmu=znfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(znfltr$coef[2:15],0)),iter=400),corr=F) # 816.8728

# gamma with log link
print(zgf0 <- gnlr(reps,dist="gamma",mu=~exp(a),pmu=4,psh=2.8)) # 936.5618
print(zgtr <- gnlr(reps,dist="gamma",mu=~exp(linear),
	linear=~as.factor(times)+as.factor(Recipe),
	pmu=c(4,rep(0,7)),psh=1),corr=F) # 924.1183
print(zgltr <- gnlr(reps,dist="gamma",mu=~exp(linear),
	linear=~times+as.factor(Recipe),
	pmu=c(4,rep(0,3)),psh=1),corr=F) # 921.2571
print(zgfn <- gnlr(reps,dist="gamma",mu=~exp(linear),
	linear=~as.factor(times)*as.factor(Recipe),
	pmu=c(4,rep(0,17)),psh=1),corr=F) # 932.3578
print(zgff <- gnlr(reps,dist="gamma",mu=~exp(linear),linear=~individuals,
	pmu=c(4,rep(0,14)),psh=2.8),corr=F) # 849.364 diff=101.1978
zgf0$maxlike-zgff$maxlike
print(zgffr <- gnlr(reps,dist="gamma",mu=~exp(linear),
	linear=~individuals+as.factor(Recipe),
	pmu=c(4,rep(0,16)),psh=2.8),corr=F) # 847.8542 diff=3.5098
zgff$maxlike-zgffr$maxlike
print(zgft <- gnlr(reps,dist="gamma",mu=~exp(linear),linear=~individuals+
	as.factor(times),pmu=c(4,rep(0,19)),psh=1),corr=F) # 812.2307
print(zgfltr <- gnlr(reps,dist="gamma",mu=~exp(linear),linear=~individuals+
	times+as.factor(Recipe),pmu=c(4,rep(0,17)),psh=1),corr=F)
	# 808.1546
print(zgftr <- gnlr(reps,dist="gamma",mu=~exp(linear),linear=~individuals+
	as.factor(times)+as.factor(Recipe),
	pmu=c(4,rep(0,21)),psh=1),corr=F) # 809.4089 diff=43.4453
zgffr$maxlike-zgftr$maxlike
print(zgfi <- gnlr(reps,dist="gamma",mu=~exp(linear),linear=~individuals+
	as.factor(Recipe)*as.factor(times),
	pmu=c(4,rep(0,31)),psh=1),corr=F) # 814.9318 diff=4.477009
zgftr$maxlike-zgfi$maxlike

# gamma-normal with log link
print(zgmmltr <- gnlmm(reps,dist="gamma",mu=~exp(linear),
	linear=~times+as.factor(Recipe),pmu=zgfltr$coef[c(1,16:18)],
	psh=3.84,psd=0.12,points=5),corr=F) # 826.0332
print(zgmmtr <- gnlmm(reps,dist="gamma",mu=~exp(linear),
	linear=~as.factor(times)+as.factor(Recipe),pmu=zgftr$coef[c(1,16:22)],
	psh=3.84,psd=0.12,points=5),corr=F) # 827.4235
print(zgmmi <- gnlmm(reps,dist="gamma",mu=~exp(linear),
	linear=~as.factor(times)*as.factor(Recipe),
	pmu=zgfi$coef[c(1,16:32)],psh=3.88,psd=0.12,points=5),corr=F) # 833.161

print(hnlmix(reps,mu=~exp(a+rep+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5)),dist="gamma",
	mixture="normal",random="rep",pmu=zgft$coef[c(1,16:20)],
	psh=3.85,prand=c(zgft$coef[2:15],0),iter=400),corr=F) # 812.232
print(hnlmix(reps,mu=~exp(a+rep+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="normal",random="rep",pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=c(zgftr$coef[2:15],0),iter=400),corr=F) # 808.1588
print(hnlmix(reps,mu=~exp(a+rep+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="normal",random="rep",pmu=zgftr$coef[c(1,16:22)],
	psh=3.85,prand=c(zgftr$coef[2:15],0),iter=400),corr=F) # 809.413
print(hnlmix(reps,mu=~exp(a+rep+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
	e4*(times==4)+e5*(times==5))*(Recipe==2)),dist="gamma",
	mixture="normal",random="rep",pmu=zgfi$coef[c(1,16:32)],psh=1,
	prand=c(zgfi$coef[2:15],0),iter=400),corr=F) # 814.9386

# gamma-gamma with log link
print(gnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="gamma",random="rep",psh=3.82,
	pmix=3.49,pmu=c(3.27,0.05,0.059,0.003)),corr=F) # 827.4366
#	dist="gamma",mixture="gamma",random="rep",psh=3.87,
#	pmix=3.5,pmu=zgfltr$coef[c(1,16:18)]),corr=F) # 827.4366
#print(gnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2),
#	dist="gamma",mixture="gamma",
#	random="rep",psh=3.87,pmix=3.5,pmu=zgftr$coef[c(1,16:22)]),corr=F) # 
#print(gnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
#	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
#	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
#	e4*(times==4)+e5*(times==5))*(Recipe==2)),dist="gamma",mixture="gamma",
#	random="rep",psh=3.87,pmix=3.5,pmu=zgfi$coef[c(1,16:32)]),corr=F) # 

#3.549781e+00 -2.527451e-01 -1.895099e-01 -9.612813e-02 -9.660532e-02
# 2.859861e-02  4.287759e-02  1.040716e-02  3.385864e-02  6.625771e-02
#-6.266760e-02  2.980460e-02  4.115533e-05  5.384853e-03  1.191717e-02
#-1.219904e-02 -1.359833e-02 -5.424508e-02  3.866329e+00  3.526519e+00

print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5)),dist="gamma",
	mixture="gamma",random="rep",pmu=zgft$coef[c(1,16:20)],
	psh=3.85,prand=exp(c(zgft$coef[2:15],0)),iter=400),corr=F) # 811.2336
print(hnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="gamma",random="rep",pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 807.166
print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="gamma",random="rep",pmu=zgftr$coef[c(1,16:22)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 808.4204
print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
	e4*(times==4)+e5*(times==5))*(Recipe==2)),
	dist="gamma",mixture="gamma",random="rep",pmu=zgfi$coef[c(1,16:32)],
	psh=3.85,prand=exp(c(zgfi$coef[2:15],0)),iter=400),corr=F) # 814.0592

# gamma-inverse gamma with log link (1)
print(gnlmix(reps,mu=~exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2))/rep,
	dist="gamma",mixture="gamma",random="rep",psh=3.82,
	pmix=3.61,pmu=c(3.24,0.05,0.059,0.003)),corr=F) # 826.4545
#	dist="gamma",mixture="gamma",random="rep",psh=3.87,
#	pmix=3.5,pmu=zgfltr$coef[c(1,16:18)]),corr=F) # 826.4545
#print(gnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2))/rep,
#	dist="gamma",mixture="gamma",random="rep",psh=3.85,pmix=1,
#	pmu=zgftr$coef[c(1,16:22)]),corr=F) # 
#print(gnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
#	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
#	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
#	e4*(times==4)+e5*(times==5))*(Recipe==2))/rep,
#	dist="gamma",mixture="gamma",random="rep",psh=3.85,pmix=1,
#	pmu=zgfi$coef[c(1,16:32)]),corr=F) # 

print(hnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5))/rep,dist="gamma",
	mixture="gamma",random="rep",pmu=zgft$coef[c(1,16:20)],
	psh=3.85,prand=exp(c(zgft$coef[2:15],0)),iter=400),corr=F) # 811.2336
print(hnlmix(reps,mu=~exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2))/rep,
	dist="gamma",mixture="gamma",random="rep",pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 807.1664
# Lee and Nelder value of pmix: 808.155
print(hnlmix(reps,mu=~exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2))/rep,
	dist="gamma",mixture="gamma",random="rep",pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400,pmix=219),corr=F)
print(hnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2))/rep,
	dist="gamma",mixture="gamma",random="rep",pmu=zgftr$coef[c(1,16:22)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 808.4202
print(hnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
	e4*(times==4)+e5*(times==5))*(Recipe==2))/rep,
	dist="gamma",mixture="gamma",random="rep",pmu=zgfi$coef[c(1,16:32)],
	psh=3.85,prand=exp(c(zgfi$coef[2:15],0)),iter=400),corr=F) # 813.95

# gamma-inverse gamma with log link (2)
print(gnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="inverse gamma",random="rep",psh=3.82,
	pmix=3.61,pmu=c(3.24,0.05,0.059,0.003)),corr=F) # 826.4546
#print(gnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2))/rep,
#	dist="gamma",mixture="gamma",random="rep",psh=3.85,pmix=1,
#	pmu=zgftr$coef[c(1,16:22)]),corr=F) # 
#print(gnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
#	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
#	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
#	e4*(times==4)+e5*(times==5))*(Recipe==2))/rep,
#	dist="gamma",mixture="gamma",random="rep",psh=3.85,pmix=1,
#	pmu=zgfi$coef[c(1,16:32)]),corr=F) # 

print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5)),dist="gamma",
	mixture="inverse gamma",random="rep",pmu=zgft$coef[c(1,16:20)],
	psh=3.85,prand=exp(c(zgft$coef[2:15],0)),iter=400),corr=F) # 811.3433
print(hnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="inverse gamma",random="rep",
	pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 807.2905
# Lee and Nelder value of pmix: 807.6568
print(hnlmix(reps,mu=~exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2))/rep,
	dist="gamma",mixture="inverse gamma",random="rep",
	pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400,pmix=219),corr=F) # 807.6568
print(hnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2))/rep,
	dist="gamma",mixture="inverse gamma",
	random="rep",pmu=zgftr$coef[c(1,16:22)],psh=3.85,
	prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 808.6078
print(hnlmix(reps,mu=~exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
	e4*(times==4)+e5*(times==5))*(Recipe==2))/rep,dist="gamma",
	mixture="inverse gamma",random="rep",pmu=zgfi$coef[c(1,16:32)],
	psh=3.85,prand=exp(c(zgfi$coef[2:15],0)),iter=400),corr=F) # 814.1308

# gamma-inverse Gauss with log link
print(gnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="inverse Gauss",random="rep",psh=3.82,
	pmix=-3.53,pmu=c(3.27,0.05,0.059,0.003)),corr=F) # 826.9208
#	dist="gamma",mixture="inverse Gauss",random="rep",psh=3.87,
#	pmix=0.05,pmu=zgfltr$coef[c(1,16:18)]),corr=F) # 826.9208
#print(gnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)),
#	dist="gamma",mixture="inverse Gauss",random="rep",psh=3.85,pmix=1,
#	pmu=zgftr$coef[c(1,16:22)]),corr=F) # 
#print(gnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
#	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
#	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
#	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
#	e4*(times==4)+e5*(times==5))*(Recipe==2)),
#	dist="gamma",mixture="inverse Gauss",random="rep",psh=3.85,pmix=1,
#	pmu=zgfi$coef[c(1,16:32)]),corr=F) # 

print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+
	b3*(times==3)+b4*(times==4)+b5*(times==5)),dist="gamma",
	mixture="inverse Gauss",random="rep",pmu=zgft$coef[c(1,16:20)],
	psh=3.85,prand=exp(c(zgft$coef[2:15],0)),iter=400),corr=F) # 811.2321
print(hnlmix(reps,mu=~rep*exp(a+b1*times+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="inverse Gauss",random="rep",
	pmu=zgfltr$coef[c(1,16:18)],
	psh=3.85,prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 807.1586
print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)),
	dist="gamma",mixture="inverse Gauss",
	random="rep",pmu=zgftr$coef[c(1,16:22)],psh=3.85,
	prand=exp(c(zgftr$coef[2:15],0)),iter=400),corr=F) # 808.413
print(hnlmix(reps,mu=~rep*exp(a+b1*(times==1)+b2*(times==2)+b3*(times==3)+
	b4*(times==4)+b5*(times==5)+c1*(Recipe==1)+c2*(Recipe==2)+
	(d1*(times==1)+d2*(times==2)+d3*(times==3)+d4*(times==4)+
	d5*(times==5))*(Recipe==1)+(e1*(times==1)+e2*(times==2)+e3*(times==3)+
	e4*(times==4)+e5*(times==5))*(Recipe==2)),dist="gamma",
	mixture="inverse Gauss",random="rep",pmu=zgfi$coef[c(1,16:32)],
	psh=3.85,prand=exp(c(zgfi$coef[2:15],0)),iter=400),corr=F) # 814.0508
